summaryrefslogtreecommitdiff
path: root/chat/zenicb/patches/patch-ab
blob: 90dd978db24b8ae0ebaf6dc0ab710cef725ba26e (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
$NetBSD: patch-ab,v 1.1 2003/02/12 15:53:09 yyamano Exp $

--- src/zenicb-example.el.orig	Mon Jul 20 07:12:55 1998
+++ src/zenicb-example.el
@@ -89,10 +89,11 @@
 ;;; insert time-stamps into the buffer at least every 10 minutes.
 (load-library "zenicb-stamp")
 
 ;;; fsf emacs doesn't have read-passwd
 (cond ((= (string-to-int emacs-version) 18)
        (fset 'read-passwd 'read-from-minibuffer))
-      ((not (string-match "XEmacs" emacs-version))
+      ((and (not (string-match "XEmacs" emacs-version))
+	(= (string-to-int emacs-version) 19))
        (require 'ange-ftp)
        (fset 'read-passwd 'ange-ftp-read-passwd)))
@@ -89,10 +89,11 @@
 (load-library "zenicb-stamp")
 
-;;; fsf emacs doesn't have read-passwd
+;;; fsf emacs 18.x and 19.x don't have read-passwd
 (cond ((= (string-to-int emacs-version) 18)
        (fset 'read-passwd 'read-from-minibuffer))